==> dar-2.7.19_0.darwin_24.x86_64.tbz2: opt/local/include/dar/libdar_config.h <==
#define BACKTRACE_AVAILABLE_FOR_LIBDAR 1
#define CRYPTO_AVAILABLE_FOR_LIBDAR 1
#define DAR_LIBDAR_VERSION "2.7.19"
#define DAR_ENABLE_NLS 1
#define EXPECTED_MAJ_LIBDAR_VERSION_THREADAR "1"
#define GPGME_MIN_LIBDAR_VERSION "1.2.0"
#define LIBDAR_HAS_ARGON2_H 1
#define LIBDAR_HAS_ARPA_INET_H 1
#define LIBDAR_HAS_BZLIB_H 1
#define LIBDAR_HAS_CFLOCALECOPYPREFERREDLANGUAGES 1
#define LIBDAR_HAS_CFPREFERENCESCOPYAPPVALUE 1
#define LIBDAR_HAS_CTIME_R 1
#define LIBDAR_HAS_CTYPE_H 1
#define LIBDAR_HAS_CURL_CURL_H 1
#define LIBDAR_HAS_DCGETTEXT 1
#define LIBDAR_HAS_DECL_SYS_SIGLIST 1
#define LIBDAR_HAS_DIRENT_H 1
#define LIBDAR_HAS_DLFCN_H 1
#define LIBDAR_HAS_ERRNO_H 1
#define LIBDAR_HAS_EXECINFO_H 1
#define LIBDAR_HAS_FCNTL_H 1
#define LIBDAR_HAS_FDOPENDIR 1
#define LIBDAR_HAS_FNMATCH 1
#define LIBDAR_HAS_FNMATCH_H 1
#define LIBDAR_HAS_FORK 1
#define LIBDAR_HAS_GCRYPT_H 1
#define LIBDAR_HAS_GETGRNAM_R 1
#define LIBDAR_HAS_GETOPT_H 1
#define LIBDAR_HAS_GETOPT_IN_UNISTD_H 1
#define LIBDAR_HAS_GETOPT_LONG 1
#define LIBDAR_HAS_GETPWNAM_R 1
#define LIBDAR_HAS_GETTEXT 1
#define LIBDAR_HAS_GPGME_H 1
#define LIBDAR_HAS_GRP_H 1
#define LIBDAR_HAS_ICONV 1
#define LIBDAR_HAS_INTTYPES_H 1
#define LIBDAR_HAS_LCHOWN 1
#define LIBDAR_HAS_LIBARGON2 1
#define LIBDAR_HAS_LIBBZ2 1
#define LIBDAR_HAS_LIBC 1
#define LIBDAR_HAS_LIBCURL 1
#define LIBDAR_HAS_LIBDL 1
#define LIBDAR_HAS_LIBGCRYPT 1
#define LIBDAR_HAS_LIBGPGME 1
#define LIBDAR_HAS_LIBGPG_ERROR 1
#define LIBDAR_HAS_LIBINTL_H 1
#define LIBDAR_HAS_LIBLZ4 1
#define LIBDAR_HAS_LIBLZMA 1
#define LIBDAR_HAS_LIBLZO2 1
#define LIBDAR_HAS_LIBPTHREAD 1
#define LIBDAR_HAS_LIBRSYNC 1
#define LIBDAR_HAS_LIBRSYNC_H 1
#define LIBDAR_HAS_LIBZ 1
#define LIBDAR_HAS_LIBZSTD 1
#define LIBDAR_HAS_LIMITS_H 1
#define LIBDAR_HAS_LOCALTIME_R 1
#define LIBDAR_HAS_LUTIMES 1
#define LIBDAR_HAS_LZ4_H 1
#define LIBDAR_HAS_LZMA_H 1
#define LIBDAR_HAS_LZO_LZO1X_H 1
#define LIBDAR_HAS_MALLOC 1
#define LIBDAR_HAS_MKDIR 1
#define LIBDAR_HAS_NETINET_IN_H 1
#define LIBDAR_HAS_OPTRESET 1
#define LIBDAR_HAS_PTHREAD_H 1
#define LIBDAR_HAS_PWD_H 1
#define LIBDAR_HAS_READDIR_R 1
#define LIBDAR_HAS_REGCOMP 1
#define LIBDAR_HAS_REGEX_H 1
#define LIBDAR_HAS_RMDIR 1
#define LIBDAR_HAS_SIGNAL_H 1
#define LIBDAR_HAS_STDDEF_H 1
#define LIBDAR_HAS_STDINT_H 1
#define LIBDAR_HAS_STDIO_H 1
#define LIBDAR_HAS_STDLIB_H 1
#define LIBDAR_HAS_STRERROR_R 1
#define LIBDAR_HAS_STRINGS_H 1
#define LIBDAR_HAS_STRING_H 1
#define LIBDAR_HAS_STRUCT_STAT_ST_RDEV 1
#define LIBDAR_HAS_SYS_IOCTL_H 1
#define LIBDAR_HAS_SYS_SOCKET_H 1
#define LIBDAR_HAS_SYS_STAT_H 1
#define LIBDAR_HAS_SYS_TIME_H 1
#define LIBDAR_HAS_SYS_TYPES_H 1
#define LIBDAR_HAS_SYS_UN_H 1
#define LIBDAR_HAS_SYS_UTSNAME_H 1
#define LIBDAR_HAS_SYS_WAIT_H 1
#define LIBDAR_HAS_SYS_XATTR_H 1
#define LIBDAR_HAS_TERMIOS_H 1
#define LIBDAR_HAS_TIME_H 1
#define LIBDAR_HAS_UNISTD_H 1
#define LIBDAR_HAS_UTIME 1
#define LIBDAR_HAS_UTIME_H 1
#define LIBDAR_HAS_UTIME_NULL 1
#define LIBDAR_HAS_VFORK 1
#define LIBDAR_HAS_WCHAR_H 1
#define LIBDAR_HAS_WCTYPE_H 1
#define LIBDAR_HAS_WORKING_FORK 1
#define LIBDAR_HAS_WORKING_VFORK 1
#define LIBDAR_HAS_ZLIB_H 1
#define LIBDAR_HAS_ZSTD_H 1
#define LIBARGON2_AVAILABLE_FOR_LIBDAR 1
#define LIBBZ2_AVAILABLE_FOR_LIBDAR 1
#define LIBCURL_AVAILABLE_FOR_LIBDAR 1
#define LIBDAR_BIRTHTIME 1
#define LIBDAR_FAST_DIR 1
#define LIBDAR_TIME_ACCURACY_MICROSECOND 6
#define LIBDAR_TIME_ACCURACY_NANOSECOND 9
#define LIBDAR_TIME_ACCURACY_SECOND 0
#define LIBDAR_TIME_READ_ACCURACY 0
#define LIBDAR_TIME_WRITE_ACCURACY 9
#define LIBLZ4_AVAILABLE_FOR_LIBDAR 1
#define LIBLZMA_AVAILABLE_FOR_LIBDAR 1
#define LIBLZO2_AVAILABLE_FOR_LIBDAR 1
#define LIBRSYNC_AVAILABLE_FOR_LIBDAR 1
#define LIBZSTD_AVAILABLE_FOR_LIBDAR 1
#define LIBZ_AVAILABLE_FOR_LIBDAR 1
#define MIN_MAJ_LIBDAR_VERSION_ZSTD "1"
#define MIN_MED_LIBDAR_VERSION_THREADAR "3"
#define MIN_MIN_LIBDAR_VERSION_THREADAR "1"
#define MIN_MIN_LIBDAR_VERSION_ZSTD "3"
#define MIN_LIBDAR_VERSION_GCRYPT "1.4.0"
#define MIN_LIBDAR_VERSION_GCRYPT_HASH_BUG "1.6.0"
#define LIBDAR_MUTEX_WORKS 1
#define DAR_PACKAGE "dar"
#define DAR_PACKAGE_BUGREPORT "https://github.com/Edrusb/DAR/issues"
#define DAR_PACKAGE_NAME "DAR"
#define DAR_PACKAGE_STRING "DAR 2.7.19"
#define DAR_PACKAGE_TARNAME "dar"
#define DAR_PACKAGE_URL ""
#define DAR_PACKAGE_LIBDAR_VERSION "2.7.19"
#define LIBDAR_SIZEOF_OFF_T 8
#define LIBDAR_SIZEOF_SIZE_T 8
#define LIBDAR_SIZEOF_TIME_T 8
#define LIBDAR_STDC_HEADERS 1
#define LIBDAR_VERSION "2.7.19"

==> dar-2.8.3_0.darwin_24.x86_64.tbz2: opt/local/include/dar/libdar_config.h <==
#define BACKTRACE_AVAILABLE_FOR_LIBDAR 1
#define CRYPTO_AVAILABLE_FOR_LIBDAR 1
#define DAR_LIBDAR_VERSION "2.8.3"
#define DAR_ENABLE_NLS 1
#define EXPECTED_MAJ_LIBDAR_VERSION_THREADAR "1"
#define GPGME_MIN_LIBDAR_VERSION "1.2.0"
#define LIBDAR_HAS_ARGON2_H 1
#define LIBDAR_HAS_ARPA_INET_H 1
#define LIBDAR_HAS_BZLIB_H 1
#define LIBDAR_HAS_CFLOCALECOPYPREFERREDLANGUAGES 1
#define LIBDAR_HAS_CFPREFERENCESCOPYAPPVALUE 1
#define LIBDAR_HAS_CTIME_R 1
#define LIBDAR_HAS_CTYPE_H 1
#define LIBDAR_HAS_CURL_CURL_H 1
#define LIBDAR_HAS_DCGETTEXT 1
#define LIBDAR_HAS_DIRENT_H 1
#define LIBDAR_HAS_DLFCN_H 1
#define LIBDAR_HAS_ERRNO_H 1
#define LIBDAR_HAS_EXECINFO_H 1
#define LIBDAR_HAS_FCNTL_H 1
#define LIBDAR_HAS_FDOPENDIR 1
#define LIBDAR_HAS_FNMATCH 1
#define LIBDAR_HAS_FNMATCH_H 1
#define LIBDAR_HAS_FORK 1
#define LIBDAR_HAS_GCRYPT_H 1
#define LIBDAR_HAS_GETGRNAM_R 1
#define LIBDAR_HAS_GETOPT_H 1
#define LIBDAR_HAS_GETOPT_IN_UNISTD_H 1
#define LIBDAR_HAS_GETOPT_LONG 1
#define LIBDAR_HAS_GETPWNAM_R 1
#define LIBDAR_HAS_GETTEXT 1
#define LIBDAR_HAS_GPGME_H 1
#define LIBDAR_HAS_GRP_H 1
#define LIBDAR_HAS_ICONV 1
#define LIBDAR_HAS_INTTYPES_H 1
#define LIBDAR_HAS_LCHOWN 1
#define LIBDAR_HAS_LIBARGON2 1
#define LIBDAR_HAS_LIBBZ2 1
#define LIBDAR_HAS_LIBC 1
#define LIBDAR_HAS_LIBCURL 1
#define LIBDAR_HAS_LIBDL 1
#define LIBDAR_HAS_LIBGCRYPT 1
#define LIBDAR_HAS_LIBGPGME 1
#define LIBDAR_HAS_LIBGPG_ERROR 1
#define LIBDAR_HAS_LIBINTL_H 1
#define LIBDAR_HAS_LIBLZ4 1
#define LIBDAR_HAS_LIBLZMA 1
#define LIBDAR_HAS_LIBLZO2 1
#define LIBDAR_HAS_LIBPTHREAD 1
#define LIBDAR_HAS_LIBRSYNC 1
#define LIBDAR_HAS_LIBRSYNC_H 1
#define LIBDAR_HAS_LIBSSH 1
#define LIBDAR_HAS_LIBSSH_LIBSSH_H 1
#define LIBDAR_HAS_LIBZ 1
#define LIBDAR_HAS_LIBZSTD 1
#define LIBDAR_HAS_LIMITS_H 1
#define LIBDAR_HAS_LOCALTIME_R 1
#define LIBDAR_HAS_LUTIMES 1
#define LIBDAR_HAS_LZ4_H 1
#define LIBDAR_HAS_LZMA_H 1
#define LIBDAR_HAS_LZO_LZO1X_H 1
#define LIBDAR_HAS_MALLOC 1
#define LIBDAR_HAS_MKDIR 1
#define LIBDAR_HAS_NETINET_IN_H 1
#define LIBDAR_HAS_OPTRESET 1
#define LIBDAR_HAS_PTHREAD_H 1
#define LIBDAR_HAS_PWD_H 1
#define LIBDAR_HAS_READDIR_R 1
#define LIBDAR_HAS_REGCOMP 1
#define LIBDAR_HAS_REGEX_H 1
#define LIBDAR_HAS_RMDIR 1
#define LIBDAR_HAS_SIGNAL_H 1
#define LIBDAR_HAS_STDDEF_H 1
#define LIBDAR_HAS_STDINT_H 1
#define LIBDAR_HAS_STDIO_H 1
#define LIBDAR_HAS_STDLIB_H 1
#define LIBDAR_HAS_STRERROR_R 1
#define LIBDAR_HAS_STRINGS_H 1
#define LIBDAR_HAS_STRING_H 1
#define LIBDAR_HAS_STRUCT_STAT_ST_RDEV 1
#define LIBDAR_HAS_SYS_IOCTL_H 1
#define LIBDAR_HAS_SYS_SOCKET_H 1
#define LIBDAR_HAS_SYS_STAT_H 1
#define LIBDAR_HAS_SYS_TIME_H 1
#define LIBDAR_HAS_SYS_TYPES_H 1
#define LIBDAR_HAS_SYS_UN_H 1
#define LIBDAR_HAS_SYS_UTSNAME_H 1
#define LIBDAR_HAS_SYS_WAIT_H 1
#define LIBDAR_HAS_SYS_XATTR_H 1
#define LIBDAR_HAS_TERMIOS_H 1
#define LIBDAR_HAS_TIME_H 1
#define LIBDAR_HAS_UNISTD_H 1
#define LIBDAR_HAS_UTIME 1
#define LIBDAR_HAS_UTIME_H 1
#define LIBDAR_HAS_UTIME_NULL 1
#define LIBDAR_HAS_VFORK 1
#define LIBDAR_HAS_WCHAR_H 1
#define LIBDAR_HAS_WCTYPE_H 1
#define LIBDAR_HAS_WORKING_FORK 1
#define LIBDAR_HAS_WORKING_VFORK 1
#define LIBDAR_HAS_ZLIB_H 1
#define LIBDAR_HAS_ZSTD_H 1
#define LIBARGON2_AVAILABLE_FOR_LIBDAR 1
#define LIBBZ2_AVAILABLE_FOR_LIBDAR 1
#define LIBCURL_AVAILABLE_FOR_LIBDAR 1
#define LIBDAR_BIRTHTIME 1
#define LIBDAR_FAST_DIR 1
#define LIBDAR_TIME_ACCURACY_MICROSECOND 6
#define LIBDAR_TIME_ACCURACY_NANOSECOND 9
#define LIBDAR_TIME_ACCURACY_SECOND 0
#define LIBDAR_TIME_READ_ACCURACY 0
#define LIBDAR_TIME_WRITE_ACCURACY 9
#define LIBLZ4_AVAILABLE_FOR_LIBDAR 1
#define LIBLZMA_AVAILABLE_FOR_LIBDAR 1
#define LIBLZO2_AVAILABLE_FOR_LIBDAR 1
#define LIBRSYNC_AVAILABLE_FOR_LIBDAR 1
#define LIBSSH_AVAILABLE_FOR_LIBDAR 1
#define LIBZSTD_AVAILABLE_FOR_LIBDAR 1
#define LIBZ_AVAILABLE_FOR_LIBDAR 1
#define MIN_MAJ_LIBDAR_VERSION_ZSTD "1"
#define MIN_MED_LIBDAR_VERSION_THREADAR "5"
#define MIN_MIN_LIBDAR_VERSION_THREADAR "0"
#define MIN_MIN_LIBDAR_VERSION_ZSTD "3"
#define MIN_LIBDAR_VERSION_GCRYPT "1.4.0"
#define MIN_LIBDAR_VERSION_GCRYPT_HASH_BUG "1.6.0"
#define LIBDAR_MUTEX_WORKS 1
#define DAR_PACKAGE "dar"
#define DAR_PACKAGE_BUGREPORT "http://sourceforge.net/tracker/?group_id=65612&atid=511612"
#define DAR_PACKAGE_NAME "DAR"
#define DAR_PACKAGE_STRING "DAR 2.8.3"
#define DAR_PACKAGE_TARNAME "dar"
#define DAR_PACKAGE_URL ""
#define DAR_PACKAGE_LIBDAR_VERSION "2.8.3"
#define LIBDAR_SIZEOF_OFF_T 8
#define LIBDAR_SIZEOF_SIZE_T 8
#define LIBDAR_SIZEOF_TIME_T 8
#define LIBDAR_VERSION "2.8.3"
